@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -72,13 +72,6 @@ web service.
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    # common objects
-    local $Kernel::OM = Kernel::System::ObjectManager->new(
-        'Kernel::System::Log' => {
-            LogPrefix => 'GenericInterfaceProvider',
-        },
-    );
-
     #
     # First, we need to locate the desired webservice and load its configuration data.
     #
@@ -211,6 +204,8 @@ sub Run {
     {
         my $MappingInObject = Kernel::GenericInterface::Mapping->new(
             DebuggerObject => $DebuggerObject,
+            Operation      => $Operation,
+            OperationType  => $ProviderConfig->{Operation}->{$Operation}->{Type},
             MappingConfig =>
                 $ProviderConfig->{Operation}->{$Operation}->{MappingInbound},
         );
@@ -254,6 +249,7 @@ sub Run {
 
     my $OperationObject = Kernel::GenericInterface::Operation->new(
         DebuggerObject => $DebuggerObject,
+        Operation      => $Operation,
         OperationType  => $ProviderConfig->{Operation}->{$Operation}->{Type},
         WebserviceID   => $WebserviceID,
     );
@@ -311,6 +307,8 @@ sub Run {
     {
         my $MappingOutObject = Kernel::GenericInterface::Mapping->new(
             DebuggerObject => $DebuggerObject,
+            Operation      => $Operation,
+            OperationType  => $ProviderConfig->{Operation}->{$Operation}->{Type},
             MappingConfig =>
                 $ProviderConfig->{Operation}->{$Operation}->{MappingOutbound},
         );
